import 'package:flutter/material.dart';

final Color shadowWhiteColor = const Color.fromRGBO(0, 45, 96, 0.08);
final Color shadowColor = const Color.fromRGBO(0, 0, 0, 0.08);
final double shadowBlurRadius = 20;
final Offset shadowOffset = const Offset(0, 3);

BoxShadow customTileBoxShadow(bool onWhiteBackground) => BoxShadow(
      color: onWhiteBackground ? shadowWhiteColor : shadowColor,
      offset: shadowOffset,
      blurRadius: shadowBlurRadius,
    );

BorderRadius tileBorderRadius({double? borderRadius}) =>
    BorderRadius.all(Radius.circular(borderRadius ?? 8));

class CustomTile extends StatelessWidget {
  final Widget? child;
  final bool? onWhiteBackground;
  final Color? color;
  final double? borderRadius;
  final Function? onClick;
  CustomTile({
    this.child,
    this.onWhiteBackground,
    this.color,
    this.borderRadius,
    this.onClick,
  });
  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: onClick as void Function()?,
      child: Container(
        decoration: BoxDecoration(
          color: color ?? Colors.white,
          borderRadius: tileBorderRadius(borderRadius: borderRadius),
          boxShadow: [
            customTileBoxShadow(onWhiteBackground ?? false),
          ],
        ),
        child: ClipRRect(
          borderRadius: tileBorderRadius(borderRadius: borderRadius),
          child: child,
        ),
      ),
    );
  }
}
